# conrep type

Puppet::Type.newtype(:conrep) do
	@doc = "This type/provider uses the conrep binary to modify BIOS settings on HP servers. 

Usage:

  puppet resource conrep

  puppet apply -e 'conrep{"default": hyperthreading => "Disabled"}'

Note: the name of the resource is hardcoded to 'default'. This is because each server has only one set of BIOS settings; when represented as a resource they need a name, and 'default' seems like a sensible choice.

The names of the settings supported by BIOS revisions varies. The gen_conrep_type.rb script can be used to regenerate the Puppet type to reflect changes in the setting names:

./gen_conrep_type.rb conrep.xml > lib/puppet/type/conrep.rb

"

	# Type must be ensurable as we must use exists?, because as per p. 46 of 
	# Puppet Types and Providers: properties other than ensure are only 
	# *individually* managed when ensure is set to present and the resource 
	# already exists. When a resource state is absent, Puppet ignores any 
	# specified # resource property.
	ensurable

	newparam(:name, :namevar => true) do
	end

	newparam(:flagchanges) do
		newvalues(:true, :false)
		defaultto(:false)
	end

	newparam(:appendchanges) do
		newvalues(:true, :false)
		defaultto(:false)
	end

	newparam(:flagfile) do
		defaultto('/tmp/conrep_changes')
		validate do |path|
			if path.include?('..')
				fail("Path to flagfile must not contains '..'")
			elsif ! ( path.start_with?('/tmp') or path.start_with?('/var/tmp') )
				fail("Path to flagfile must start with '/tmp' or '/var/tmp'")
			end
		end
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(OS) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_ServerName) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_ServerAssetTag) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_ServerPrimaryOS) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_ServerMiscInfo) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_AdminName) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_AdminPhone) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 	newproperty(IMD_AdminPager) do
		newvalues()
	end

gen_conrep_type.rb:121
propertyName = section.attributes['name']
(rdb:1) 